#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IF_ELSE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IF_ELSE_HPP_INCLUDED

#include <nt2/operator/include/functions/scalar/if_else.hpp>

#endif
